# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u0B85',
            '\u0B86',
            '\u0B87',
            '\u0B88',
            '\u0B89',
            '\u0B8A',
            '\u0BB0\u0BC1\u02BD',
            '\u0BB0\u0BC2\u02BD',
            '\u0BB2\u0BC1\u02BD',
            '\u0BB2\u0BC2\u02BD',
            '\u0B8F',
            '\u0B90',
            '\u0B93',
            '\u0B94',
            ]

SouthVowelMap = [
                '\u0B8E',
                '\u0B92',
                ]

ModernVowelMap = [
                 '\u0B8E\u02BD',
                 '\u0B86\u02BD',
                 ]

SinhalaVowelMap = [
                  '\u0B8F\u02BD'
                  ]

VowelSignMap =  [
                '\u0BBE',
                '\u0BBF',
                '\u0BC0',
                '\u0BC1',
                '\u0BC2',
                '\u0BCD\u0BB0\u0BC1\u02BD',
                '\u0BCD\u0BB0\u0BC2\u02BD',
                '\u0BCD\u0BB2\u0BC1\u02BD',
                '\u0BCD\u0BB2\u0BC2\u02BD',
                '\u0BC7',
                '\u0BC8',
                '\u0BCB',
                '\u0BCC',
                ]

SouthVowelSignMap = [
                    '\u0BC6',
                    '\u0BCA',
                    ]

ModernVowelSignMap =[
                    '\u0BC6\u02BD',
                    '\u0BBE\u02BD']

SinhalaVowelSignMap = [
                      '\u0BC7\u02BD'
                      ]

AyogavahaMap = [
               '\u0BAE\u0BCD\u02BD',
               '\u0BAE\u0BCD\u02BD',
               '꞉' # Modifying letter colon for Visarga
               ]

ViramaMap =  [
             '\u0BCD'
             ]

ConsonantMap =  [
                '\u0B95',
                '\u0B95\u02BD',
                '\u0B95\u02BD',
                '\u0B95\u02BD',
                '\u0B99',

                '\u0B9A',
                '\u0B9A\u02BD',
                '\u0B9A\u02BD',
                '\u0B9A\u02BD',
                '\u0B9E',

                '\u0B9F',
                '\u0B9F\u02BD',
                '\u0B9F\u02BD',
                '\u0B9F\u02BD',
                '\u0BA3',

                '\u0BA4',
                '\u0BA4\u02BD',
                '\u0BA4\u02BD',
                '\u0BA4\u02BD',
                '\u0BA8',

                '\u0BAA',
                '\u0BAA\u02BD',
                '\u0BAA\u02BD',
                '\u0BAA\u02BD',
                '\u0BAE',

                '\u0BAF',
                '\u0BB0',
                '\u0BB2',
                '\u0BB5',

                '\u0B9A\u02BD',
                '\u0B9A\u02BD',
                '\u0B9A\u02BD',
                '\u0B95\u02BD'
                ]

SouthConsonantMap = [
                    '\u0BB3',
                    '\u0BB4',
                    '\u0BB1',
                    '\u0BA9'
                    ]

NuktaConsonantMap =  [
                     '\u02BD\u0B95',
                     '\u02BD\u0B95',
                     '\u02BD\u0B95',
                     '\u02BD\u0B9A',
                     '\u02BD\u0B9F',
                     '\u02BD\u0B9F',
                     '\u02BD\u0BAA',
                     '\u02BD\u0BAF'
                     ]

SinhalaConsonantMap =[
                     '\u0B99\u0BCD\u02BD\u0B95',
                     '\u0B9E\u0BCD\u02BD\u0B9A',
                     '\u0BA3\u0BCD\u02BD\u0B9F',
                     '\u0BA8\u0BCD\u02BD\u0BA4',
                     '\u0BAE\u0BCD\u02BD\u0BAA',
                      ]

NuktaMap = [
           '\u02BD\u02BD'
           ]

OmMap = [
        'ஓம்'
        ]

SignMap =[
         '\u02BD\u02BD',
         '.',
         '..'
         ]

Aytham =['\u0B83']

NumeralMap = [
             '0',
             '1',
             '2',
             '3',
             '4',
             '5',
             '6',
             '7',
             '8',
             '9'
            ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])
