# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'a',
            'aa',
            'i',
            'ee',
            'u',
            'oo',
            'Ru',
            'RU',
            '~lu',
            '~lU',
            'E',
            'ai',
            'O',
            'au'
            ]

SouthVowelMap = [
                'e',
                'o',
                ]

ModernVowelMap = [
                 '~e',
                 '~o',
                 ]

SinhalaVowelMap = [
                  '~~e'
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               '~M',
               'M',
               'H'
               ]

ViramaMap =  [
             '\u00D7'
             ]

ConsonantMap =  [
                '\u006B',
                '\u006B\u0068',
                '\u0067',
                '\u0067\u0068',
                '~g',

                'c',
                'C',
                '\u006A',
                '\u006A\u0068',
                '~j',
                'T',
                'Th',
                'D',
                'Dh',
                'N',

                't',
                'th',
                'd',
                'dh',
                '\u006E',

                '\u0070',
                '\u0070\u0068',
                '\u0062',
                '\u0062\u0068',
                '\u006D',

                '\u0079',
                '\u0072',
                '\u006C',
                '\u0076',

                'S',
                'Sh',
                '\u0073',
                '\u0068',
                ]

SouthConsonantMap = [
                    'L',
                    'Lx',
                    'rx',
                    'nx'
                    ]

NuktaConsonantMap =  [
                     'kx',
                     'Kx',
                     'gx',
                     'z',
                     'Dx',
                     'Dhx',
                     'f',
                     'yx'
                     ]

SinhalaConsonantMap =[
                     '~ng',
                     '~nj',
                     '~nD',
                     '~nd',
                     '~mb',
                      ]

NuktaMap = [
           'x'
           ]

OmMap = [
        'oum'
        ]

SignMap =[
         '&',
         '|',
         '||'
         ]

Aytham =['~H']

NumeralMap = [
             '\u0030',
             '\u0031',
             '\u0032',
             '\u0033',
             '\u0034',
             '\u0035',
             '\u0036',
             '\u0037',
             '\u0038',
             '\u0039',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])