# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'a',
            'A',
            'i',
            'I',
            'u',
            'U',
            'ru\u02BD',
            'rU\u02BD',
            'lu\u02BD',
            'lU\u02BD',
            'e',
            'ai',
            'o',
            'au'
            ]

SouthVowelMap = [
                'e\u02BD',
                'o\u02BD',
                ]

ModernVowelMap = [
                'e\u02BD',
                'A',
                 ]

SinhalaVowelMap = [
                'e\u02BD',
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               'M\u02BD',
               'M',
               'h'
               ]

ViramaMap =  [
             '\u00D7'
             ]

ConsonantMap =  [
                'k',
                'K',
                'g',
                'G',
                '~',

                'c',
                'C',
                'j',
                'J',
                'Y',

                'T',
                'F',
                'D',
                'V',
                'N',

                't',
                'f',
                'd',
                '@',
                'n',

                'p',
                'P',
                'b',
                'B',
                'm',

                'y',
                'r',
                'l',
                'v',

                's\u02BD',
                's\u02BD',
                's',
                'h',
                ]

SouthConsonantMap = [
                    'L',
                    'L\u02BD',
                    'r\u02BD',
                    'n\u02BD'
                    ]

NuktaConsonantMap =  [
                     'k\u02BD',
                     'K\u02BD',
                     'g\u02BD',
                     'j\u02BD',
                    'D\u02BD',
                    'V\u02BD',
                     'P\u02BD',
                     'y\u02BD'
                     ]

SinhalaConsonantMap =[
                     'Mg\u02BD',
                     'Mj\u02BD',
                     'MD\u02BD',
                     'Md\u02BD',
                     'Mb\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD'
           ]

OmMap = [
        'oM'
        ]

SignMap =[
         '\u0027',
         '\u002E',
         '\u002E\u002E'
         ]

Aytham =['h\u02BD']

NumeralMap = [
             '\u0030',
             '\u0031',
             '\u0032',
             '\u0033',
             '\u0034',
             '\u0035',
             '\u0036',
             '\u0037',
             '\u0038',
             '\u0039',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])