# -*- coding: utf-8 -*-

# http://www.nguoicham.com/document/35/akhar-thrah-7-harei-học-chữ-cham-quot-akhar-thrah-quot-trong-7-ngày/

# Script Mapping for Devanagari

VowelMap =  [
            '\uAA00',
            '\uAA00\uAA29',
            '\uAA01',
            '\uAA01\uAA29',
            '\uAA02',
            '\uAA02\uAA29',
            '\uAA23\uAA2E',
            '\uAA23\uAA2E\uAA29',
            '\uAA24\uAA2E',
            '\uAA24\uAA2E\uAA29',
            '\uAA03',
            '\uAA04',
            '\uAA05',
            '\uAA00\uAA2F\uAA31',
            ]

SouthVowelMap = [
                '\uAA03\u02BD',
                '\uAA05\u02BD',
                ]

ModernVowelMap = [
                 '\uAA03\u02BD',
                 '\uAA00\uAA29\u02BD',
                 ]

SinhalaVowelMap = [
                  '\uAA03\u02BD'
                  ]

VowelSignMap =  [
                '\uAA29',
                '\uAA2A',
                '\uAA2B',
                '\uAA2D',
                '\uAA2D\uAA29',
                '\u02BE\uAA23\uAA2E',
                '\u02BE\uAA23\uAA2E\uAA29',
                '\u02BE\uAA24\uAA2E',
                '\u02BE\uAA24\uAA2E\uAA29',
                '\uAA2F\uAA2E',
                '\uAA30',
                '\uAA2F',
                '\uAA2F\uAA31',
                ]

SouthVowelSignMap = [
                    '\uAA2F\uAA2E\u02BD',
                    '\uAA2E\u02BD',
                    ]

ModernVowelSignMap =[
                    '\uAA2F\uAA2E\u02BD',
                    '\uAA29\u02BD']

SinhalaVowelSignMap = [
                    '\uAA2F\uAA2E\u02BD',
                      ]

AyogavahaMap = [
               '\uAA43',
               '\uAA4C',
               '\uAA4D'
               ]

ViramaMap =  [
             '\u02BE'
             ]

ConsonantMap =  [
                '\uAA06',
                '\uAA07',
                '\uAA08',
                '\uAA09',
                '\uAA0B',

                '\uAA0C',
                '\uAA0D',
                '\uAA0E',
                '\uAA0F',
                '\uAA11',

                '\uAA13\u02BD',
                '\uAA14\u02BD',
                '\uAA15\u02BD',
                '\uAA16\u02BD',
                '\uAA18\u02BD',

                '\uAA13',
                '\uAA14',
                '\uAA15',
                '\uAA16',
                '\uAA18',

                '\uAA1A',
                '\uAA1C',
                '\uAA1D',
                '\uAA1E',
                '\uAA20',

                '\uAA22',
                '\uAA23',
                '\uAA24',
                '\uAA25',

                '\uAA26\u02BD',
                '\uAA26',
                '\uAA27',
                '\uAA28'
                ]

SouthConsonantMap = [
                    '\uAA24\u02BD',
                    '\uAA24\u02BD',
                    '\uAA23\u02BD',
                    '\uAA18\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\uAA06\u02BD',
                     '\uAA07\u02BD',
                     '\uAA08\u02BD',
                     '\uAA0E\u02BD',
                     '\uAA15\u02BD',
                     '\uAA16\u02BD',
                     '\uAA1C\u02BD',
                     '\uAA25\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\uAA4C\uAA08\u02BD',
                     '\uAA12',
                     '\uAA19\u02BD',
                     '\uAA19',
                     '\uAA21',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        '\uAA05\uAA4C'
        ]

SignMap =[
         "'",
         '\uAA5D',
         '\uAA5E'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\uAA50',
             '\uAA51',
             '\uAA52',
             '\uAA53',
             '\uAA54',
             '\uAA55',
             '\uAA56',
             '\uAA57',
             '\uAA58',
             '\uAA59',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])
