# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'ᠠ᠋',
            'ᠠ᠋᠎ᠠ',
            '\u1888',
            'ᠢᠢ',
            'ᠦ',
            'ᠤᠦ',
            'ᠷᠢ',
            'ᠷᠢᠢ',
            'ᠯᠢ',
            'ᠯᠢᠢ',
            'ᠧ',
            'ᠧ\u02BCᠧ',
            'ᠣᠸᠠ',
            'ᠣᠸᠸᠠ'
            ]

SouthVowelMap = [
                'ᠧ\u02BD',
                'ᠣᠸᠠ\u02BD',
                ]

ModernVowelMap = [
                'ᠣᠸᠠ\u02BD',
                'ᠠ\u02BD',
                 ]

SinhalaVowelMap = [
                'ᠣᠸᠠ\u02BD',
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               '\u1880\u02BD',
               '\u1880',
               '\u1881'
               ]

ViramaMap =  [
             '\u00D7'
             ]

ConsonantMap =  [
                'ᢉ',
                'ᠻ',
                'ᠺ',
                'ᠺᠾ',
                'ᢊ',

                'ᢋ',
                'ᠼ',
                'ᢖ',
                'ᢖᠾ',
                'ᡛ',

                'ᢌ',
                'ᢍ',
                'ᢎ',
                'ᢎᠾ',
                'ᢏ',

                'ᢐ',
                'ᠲ',
                'ᢑ',
                'ᢑᠾ',
                'ᠨ',

                'ᢒ',
                'ᠹ',
                'ᠪ',
                'ᠪᠾ',
                'ᠮ',

                'ᠶ',
                'ᠷ',
                'ᠯ',
                'ᠸ',

                'ᠱ',
                'ᢔ',
                'ᠰ',
                'ᡙ',
                ]

SouthConsonantMap = [
                    'ᠯ\u02BD',
                    'ᠯ\u02BD',
                    'ᠷ\u02BD',
                    'ᠨ\u02BD'
                    ]

NuktaConsonantMap =  [
                    'ᢉ\u02BD',
                    'ᠻ\u02BD',
                    'ᠺ\u02BD',
                    '\u1896',
                'ᢎ\u02BD',
                'ᢎᠾ\u02BD',
                'ᠹ\u02BD',
                'ᠶ\u02BD',
                     ]

SinhalaConsonantMap =[
                     '\u1880ᠺ\u02BD',
                     '\u1880ᢖ\u02BD',
                     '\u1880ᢎ\u02BD',
                     '\u1880ᢑ\u02BD',
                     '\u1880ᠪ\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD'
           ]

OmMap = [
        'ᢀᠣᠸᠠ'
        ]

SignMap =[
         '\u02BD\u02BD\u02BD',
         '\u1802',
         '\u1802\u1802'
         ]

Aytham =['\u1881\u02BD']

NumeralMap = [
             '\u1810',
             '\u1811',
             '\u1812',
             '\u1813',
             '\u1814',
             '\u1815',
             '\u1816',
             '\u1817',
             '\u1818',
             '\u1819',
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])