# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\uABD1',
            '\uABD1\uABE5',
            '\uABCF',
            '\uABD1\uAAEB',
            '\uABCE',
            '\uABD1\uAAEC',
            '\uABD4\uABE8\u02BD',
            '\uABD4\uAAEC\u02BD',
            '\uABC2\uABE8\u02BD',
            '\uABC2\uAAEC\u02BD',
            '\uABD1\uABE6',
            '\uABD1\uABE9',
            '\uABD1\uABE3',
            '\uABD1\uABE7',
            ]

SouthVowelMap = [
                '\uABD1\uABE6\u02BD',
                '\uABD1\uABE3\u02BD',
                ]

ModernVowelMap = [
                 '\uABD1\uABE6\u02BD',
                 '\uABD1\uABE5\u02BD',
                 ]

SinhalaVowelMap = [
                  '\uABD1\uABE6\u02BD'
                  ]

VowelSignMap =  [
                 '\uABE5',
                 '\uABE4',
                 '\uAAEB',
                 '\uABE8',
                 '\uAAEC',
                 '\uABED\uABD4\uABE8\u02BD',
                 '\uABED\uABD4\uAAEC\u02BD',
                 '\uABED\uABC2\uABE8\u02BD',
                 '\uABED\uABC2\uAAEC\u02BD',
                 '\uABE6',
                 '\uABE9',
                 '\uABE3',
                 '\uABE7',
                 ]

SouthVowelSignMap = [
                     '\uABE6\u02BD',
                     '\uABE3\u02BD',
                     ]

ModernVowelSignMap =[
                     '\uABE6\u02BD',
                     '\uABE5\u02BD',
                     ]

SinhalaVowelSignMap = [
                       '\uABE6\u02BD'
                      ]

AyogavahaMap = [
               '\uABEA\u02BD',
               '\uABEA',
               '\uAAF5'
               ]

ViramaMap =  [
             '\uABED'
             ]

ConsonantMap =  [
                '\uABC0',
                '\uABC8',
                '\uABD2',
                '\uABD8',
                '\uABC9',

                '\uABC6',
                '\uAAE2',
                '\uABD6',
                '\uABD3',
                '\uAAE3',

                '\uAAE4',
                '\uAAE5',
                '\uAAE6',
                '\uAAE7',
                '\uAAE8',

                '\uABC7',
                '\uABCA',
                '\uABD7',
                '\uABD9',
                '\uABC5',

                '\uABC4',
                '\uABD0',
                '\uABD5',
                '\uABDA',
                '\uABC3',

                '\uABCC',
                '\uABD4',
                '\uABC2',
                '\uABCB',

                '\uAAE9',
                '\uAAEA',
                '\uABC1',
                '\uABCD'
                ]

SouthConsonantMap = [
                    '\uABC2\u02BD',
                    '\uABC2\u02BD',
                    '\uABD4\u02BD',
                    '\uABC5\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\uABC0\u02BD',
                     '\uABC8\u02BD',
                     '\uABD2\u02BD',
                     '\uABD6\u02BD',
                     '\uABD7\u02BD',
                     '\uABD9\u02BD',
                     '\uABD0\u02BD',
                     '\uABCC\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\uABEA\uABD2\u02BD',
                     '\uABEA\uABD6\u02BD',
                     '\uABEA\uABD7\u02BD',
                     '\uABEA\uABD7\u02BD',
                     '\uABEA\uABD5\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        '\uABD1\uABE3\uABEA'
        ]

SignMap =[
         '\u0027',
         '\uABEB',
         '\uABEB\uABEB'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']

NumeralMap = [
             '\uABF0',
             '\uABF1',
             '\uABF2',
             '\uABF3',
             '\uABF4',
             '\uABF5',
             '\uABF6',
             '\uABF7',
             '\uABF8',
             '\uABF9'
             ]

from ... import GeneralMap as GM

import os
GM.add_additional_chars(dict([(charlist, globals()[charlist]) for charlist in GM.CharmapLists]),
                        os.path.splitext(__file__)[0].split(os.path.sep)[-1])
